@@ -3,18 +3,21 @@ package Pinto::Remote;
 # ABSTRACT:  Interact with a remote Pinto repository
 
 use Moose;
+use MooseX::Types::Moose qw(Str);
 
 use Carp;
 use Class::Load;
+use LWP::UserAgent;
 
 use Pinto::Remote::Config;
+use Pinto::Remote::Logger;
 use Pinto::Remote::Batch;
 
 use namespace::autoclean;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.034'; # VERSION
+our $VERSION = '0.037'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
@@ -26,6 +29,22 @@ has config    => (
     required  => 1,
 );
 
+
+has logger    => (
+    is        => 'ro',
+    isa       => 'Pinto::Remote::Logger',
+    handles   => [ qw(debug note info whine fatal) ],
+    required  => 1,
+);
+
+
+has ua        => (
+    is        => 'ro',
+    isa       => 'LWP::UserAgent',
+    default   => sub { LWP::UserAgent->new(timeout => 600) },
+);
+
+
 has _batch => (
     is         => 'ro',
     isa        => 'Pinto::Remote::Batch',
@@ -33,22 +52,33 @@ has _batch => (
     init_arg   => undef,
 );
 
+
+has _action_base_class => (
+    is         => 'ro',
+    isa        => Str,
+    default    => 'Pinto::Remote::Action',
+    init_arg   => undef,
+);
+
 #------------------------------------------------------------------------------
 
 sub BUILDARGS {
     my ($class, %args) = @_;
 
     $args{config} ||= Pinto::Remote::Config->new( %args );
+    $args{logger} ||= Pinto::Remote::Logger->new( %args );
 
     return \%args;
 }
 
 #------------------------------------------------------------------------------
 
+
 sub new_batch {
     my ($self, %args) = @_;
 
     my $batch = Pinto::Remote::Batch->new( config => $self->config(),
+                                           logger => $self->logger(),
                                            %args );
     $self->_set_batch( $batch );
 
@@ -57,30 +87,48 @@ sub new_batch {
 
 #------------------------------------------------------------------------------
 
+
 sub add_action {
     my ($self, $action_name, %args) = @_;
 
-    my $action_class = "Pinto::Remote::Action::$action_name";
+    my $batch = $self->_batch()
+        or confess 'You must create a batch first';
 
-    eval { Class::Load::load_class($action_class); 1 }
-        or croak "Unable to load action class $action_class: $@";
+    my $action_class = $self->_action_base_class . "::$action_name";
+    Class::Load::load_class($action_class);
 
     my $action = $action_class->new( config => $self->config(),
+                                     logger => $self->logger(),
                                      %args );
 
-    $self->_batch->enqueue($action);
+    $batch->enqueue($action);
 
     return $self;
 }
 
 #------------------------------------------------------------------------------
 
+
 sub run_actions {
     my ($self) = @_;
 
-    $self->_batch() or croak 'You must create a batch first';
+    $self->_batch()
+        or confess 'You must create a batch first';
 
-    return $self->_batch->run();
+    my $result = $self->_batch->run();
+
+    return $result;
+}
+
+#------------------------------------------------------------------------------
+
+
+sub add_logger {
+    my ($self, @args) = @_;
+
+    $self->logger->add_output(@args);
+
+    return $self;
 }
 
 #------------------------------------------------------------------------------
@@ -105,7 +153,35 @@ Pinto::Remote - Interact with a remote Pinto repository
 
 =head1 VERSION
 
-version 0.034
+version 0.037
+
+=head1 METHODS
+
+=head2 new_batch( %batch_args )
+
+Prepares this Pinto::Remote to run a new batch of Actions.  Any prior
+batch will be discarded.
+
+=head2 add_action( $action_name, %action_args )
+
+Constructs the action with the given names and arguments, and adds it
+to the current batch.  You must first call C<new_batch> before you can
+add any actions.  The precise class of the Action will be formed by
+prepending 'Pinto::Remote::Action::' to the action name.  See the
+documentation for the corresponding Action class for a details about
+the arguments it supports.
+
+=head2 run_actions()
+
+Executes all the actions that are currently in the batch for this
+Pinto::Remote.  Returns a L<Pinto::Remote::Result> object that
+indicates whether the batch was successful and contains any warning or
+error messages that might have occurred along the way.
+
+=head2 add_logger( $obj )
+
+Convenience method for installing additional endpoints for logging.
+The object must be an instance of a L<Log::Dispatch::Output> subclass.
 
 =head1 SUPPORT
 
