@@ -1,64 +1,23 @@
-package Pinto::Remote::Action::Remove;
-
 # ABSTRACT: Remove a package from a remote repository
 
+package Pinto::Remote::Action::Remove;
+
 use Moose;
-use MooseX::Types::Moose qw(Str);
 
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.034'; # VERSION
+our $VERSION = '0.037'; # VERSION
 
 #------------------------------------------------------------------------------
 
-extends qw(Pinto::Remote::Action);
+extends qw( Pinto::Remote::Action );
 
 #------------------------------------------------------------------------------
 
-with qw(Pinto::Interface::Authorable);
-
-#------------------------------------------------------------------------------
-
-has path     => (
-    is       => 'ro',
-    isa      => Str,
-    required => 1,
-);
-
-
-has message => (
-    is      => 'ro',
-    isa     => Str,
-);
-
-
-has tag => (
-    is      => 'ro',
-    isa     => Str,
-);
-
-#------------------------------------------------------------------------------
-
-override execute => sub {
-    my ($self) = @_;
-
-    my %ua_args = (
-
-        Content_Type => 'form-data',
-
-        Content => [
-
-            author    => $self->author(),
-            path      => $self->path(),
-            message   => $self->message(),
-            tag       => $self->tag(),
-        ],
-    );
-
-    return $self->post('remove', %ua_args);
-};
+with qw( Pinto::Role::Interface::Action::Remove
+         Pinto::Remote::Role::Interface::CommittableAction );
 
 #------------------------------------------------------------------------------
 
@@ -79,7 +38,7 @@ Pinto::Remote::Action::Remove - Remove a package from a remote repository
 
 =head1 VERSION
 
-version 0.034
+version 0.037
 
 =head1 AUTHOR
 
