@@ -1,62 +1,22 @@
-package Pinto::Remote::Action::Statistics;
-
 # ABSTRACT: Report statistics about a remote repository
 
+package Pinto::Remote::Action::Statistics;
+
 use Moose;
-use MooseX::Types::Moose qw(Str);
-
-use Carp;
-
-use Pinto::Types qw(IO);
 
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.034'; # VERSION
+our $VERSION = '0.037'; # VERSION
 
 #------------------------------------------------------------------------------
 
-extends qw(Pinto::Remote::Action);
+extends qw( Pinto::Remote::Action );
 
 #------------------------------------------------------------------------------
 
-has out => (
-    is      => 'ro',
-    isa     => IO,
-    coerce  => 1,
-    default => sub { [fileno(STDOUT), '>'] },
-);
-
-
-has format => (
-    is       => 'ro',
-    isa      => Str,
-    default  => '',
-);
-
-#------------------------------------------------------------------------------
-
-override execute => sub {
-    my ($self) = @_;
-
-    my @format = $self->format() ? ( format => $self->format() ) : ();
-
-    my %ua_args = (
-
-        Content_Type => 'form-data',
-
-        Content => [
-
-            format        => $self->format(),
-        ],
-   );
-
-    my $response = $self->post('statistics', %ua_args);
-    print { $self->out() } $response->content();
-
-    return $response;
-};
+with qw( Pinto::Interface::Action::Statistics );
 
 #------------------------------------------------------------------------------
 
@@ -77,7 +37,7 @@ Pinto::Remote::Action::Statistics - Report statistics about a remote repository
 
 =head1 VERSION
 
-version 0.034
+version 0.037
 
 =head1 AUTHOR
 
